@@ -1,3 +1,13 @@
+#![doc = include_str!("../README.md")]
+#![deny(
+    missing_debug_implementations,
+    trivial_casts,
+    trivial_numeric_casts,
+    unused_extern_crates,
+    unused_import_braces,
+    unused_qualifications
+)]
+
 pub use async_trait::async_trait;
 pub use instant;
 pub use uuid;
